@@ -19,26 +19,22 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef DISABLE_SOURCE
 #define DISABLE_SOURCE
 
-#include "../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../constant/model/cyboi/state/state_cyboi_model.c"
-#include "../../constant/name/cyboi/state/item_state_cyboi_name.c"
-#include "../../constant/name/cyboi/state/part_state_cyboi_name.c"
-#include "../../constant/name/cyboi/state/primitive_state_cyboi_name.c"
-#include "../../constant/name/cybol/logic/activation/disable_activation_logic_cybol_name.c"
-#include "../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../executor/accessor/getter/part/name_part_getter.c"
-#include "../../executor/activator/disabler/disabler.c"
-#include "../../executor/copier/array_copier.c"
-#include "../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "constant.h"
+#include "cybol.h"
+#include "knowledge.h"
+#include "logger.h"
+#include "server.h"
 
 /**
  * Disables the given channel for message sensing.
