@@ -19,25 +19,22 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef MODIFY_SOURCE
 #define MODIFY_SOURCE
 
-#include "../../applicator/modify/array_modify.c"
-#include "../../applicator/modify/index_modify.c"
-#include "../../applicator/modify/type_modify.c"
-#include "../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../constant/name/cybol/logic/modification/modification_logic_cybol_name.c"
-#include "../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../executor/accessor/getter/part/name_part_getter.c"
-#include "../../executor/copier/array_copier.c"
-#include "../../executor/modifier/part_modifier.c"
-#include "../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "applicator.h"
+#include "constant.h"
+#include "cybol.h"
+#include "knowledge.h"
+#include "logger.h"
 
 /**
  * Modifies the destination- with the source part.
