@@ -19,24 +19,35 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef LOG_GLOBALISER_SOURCE
 #define LOG_GLOBALISER_SOURCE
 
-#include "../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../variable/type_size/integral_type_size.c"
-#include "../../variable/log_setting.c"
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "constant.h"
+#include "logger.h"
+#include "variable.h"
 
 /**
  * Initialises log global variables.
  */
 void globalise_log() {
 
+    //?? fwprintf(stdout, L"Debug: Globalise log.\n");
+
     *LOG_LEVEL = *OFF_LEVEL_LOG_CYBOI_MODEL;
 
     //
