@@ -19,15 +19,19 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef REFERENCE_COUNTER_GLOBALISER_SOURCE
 #define REFERENCE_COUNTER_GLOBALISER_SOURCE
 
-#include "../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../variable/reference_counter.c"
+//
+// Library interface
+//
+
+#include "constant.h"
+#include "variable.h"
 
 /**
  * Initialises reference counter global variables.
