@@ -19,14 +19,16 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef BAUDRATE_SERIAL_SYMBOLIC_NAME_GLOBALISER_SOURCE
 #define BAUDRATE_SERIAL_SYMBOLIC_NAME_GLOBALISER_SOURCE
 
-#include "../../../variable/symbolic_name/baudrate_serial_symbolic_name.c"
+//
+// System interface
+//
 
 #if defined(__linux__) || defined(__unix__)
     #include <termios.h>
@@ -37,12 +39,16 @@
     // The win32 api does not seem to define symbolic names for baudrates.
     // It does assign standard integer values instead:
     // http://msdn.microsoft.com/en-us/library/system.io.ports.serialport.baudrate%28v=vs.110%29.aspx?cs-save-lang=1&cs-lang=cpp#code-snippet-1
-    #include "../../../constant/model/cyboi/state/extra_integer_state_cyboi_model.c"
-    #include "../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#else
+        #else
     #error "Could not compile system. The operating system is not supported. Check out defined preprocessor macros!"
 #endif
 
+//
+// Library interface
+//
+
+#include "variable.h"
+
 //
 // The baudrates below were mostly taken from:
 //
@@ -125,18 +131,18 @@ void globalise_symbolic_name_serial_baudrate() {
     *B57600_BAUDRATE_SERIAL_SYMBOLIC_NAME = B57600;
     *B115200_BAUDRATE_SERIAL_SYMBOLIC_NAME = B115200;
     *B230400_BAUDRATE_SERIAL_SYMBOLIC_NAME = B230400;
-    //*B460800_BAUDRATE_SERIAL_SYMBOLIC_NAME = B460800;
-    //*B500000_BAUDRATE_SERIAL_SYMBOLIC_NAME = B500000;
-    //*B576000_BAUDRATE_SERIAL_SYMBOLIC_NAME = B576000;
-    //*B921600_BAUDRATE_SERIAL_SYMBOLIC_NAME = B921600;
-    //*B1000000_BAUDRATE_SERIAL_SYMBOLIC_NAME = B1000000;
-    //*B1152000_BAUDRATE_SERIAL_SYMBOLIC_NAME = B1152000;
-    //*B1500000_BAUDRATE_SERIAL_SYMBOLIC_NAME = B1500000;
-    //*B2000000_BAUDRATE_SERIAL_SYMBOLIC_NAME = B2000000;
-    //*B2500000_BAUDRATE_SERIAL_SYMBOLIC_NAME = B2500000;
-    //*B3000000_BAUDRATE_SERIAL_SYMBOLIC_NAME = B3000000;
-    //*B3500000_BAUDRATE_SERIAL_SYMBOLIC_NAME = B3500000;
-    //*B4000000_BAUDRATE_SERIAL_SYMBOLIC_NAME = B4000000;
+    // *B460800_BAUDRATE_SERIAL_SYMBOLIC_NAME = B460800;
+    // *B500000_BAUDRATE_SERIAL_SYMBOLIC_NAME = B500000;
+    // *B576000_BAUDRATE_SERIAL_SYMBOLIC_NAME = B576000;
+    // *B921600_BAUDRATE_SERIAL_SYMBOLIC_NAME = B921600;
+    // *B1000000_BAUDRATE_SERIAL_SYMBOLIC_NAME = B1000000;
+    // *B1152000_BAUDRATE_SERIAL_SYMBOLIC_NAME = B1152000;
+    // *B1500000_BAUDRATE_SERIAL_SYMBOLIC_NAME = B1500000;
+    // *B2000000_BAUDRATE_SERIAL_SYMBOLIC_NAME = B2000000;
+    // *B2500000_BAUDRATE_SERIAL_SYMBOLIC_NAME = B2500000;
+    // *B3000000_BAUDRATE_SERIAL_SYMBOLIC_NAME = B3000000;
+    // *B3500000_BAUDRATE_SERIAL_SYMBOLIC_NAME = B3500000;
+    // *B4000000_BAUDRATE_SERIAL_SYMBOLIC_NAME = B4000000;
 // Use __CYGWIN__ too, if _WIN32 is not known to mingw.
 #elif defined(_WIN32) || defined(__CYGWIN__)
     *B0_BAUDRATE_SERIAL_SYMBOLIC_NAME = *NUMBER_0_INTEGER_STATE_CYBOI_MODEL;
