@@ -19,17 +19,18 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef COMPOUND_TYPE_SIZE_GLOBALISER_SOURCE
 #define COMPOUND_TYPE_SIZE_GLOBALISER_SOURCE
 
-#include "../../../variable/type_size/compound_type_size.c"
-#include "../../../variable/type_size/integral_type_size.c"
-#include "../../../variable/type_size/pointer_type_size.c"
-#include "../../../variable/type_size/real_type_size.c"
+//
+// Library interface
+//
+
+#include "variable.h"
 
 /**
  * Initialises compound type size global variables.
