@@ -19,13 +19,17 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef DISPLAY_TYPE_SIZE_GLOBALISER_SOURCE
 #define DISPLAY_TYPE_SIZE_GLOBALISER_SOURCE
 
+//
+// System interface
+//
+
 #if defined(__linux__) || defined(__unix__)
 #elif defined(__APPLE__) && defined(__MACH__)
 // Use __CYGWIN__ too, if _WIN32 is not known to mingw.
@@ -35,7 +39,11 @@
     #error "Could not compile system. The operating system is not supported. Check out defined preprocessor macros!"
 #endif
 
-#include "../../../variable/type_size/display_type_size.c"
+//
+// Library interface
+//
+
+#include "variable.h"
 
 /**
  * Initialises display type size global variables.
