@@ -19,14 +19,18 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef REAL_TYPE_SIZE_GLOBALISER_SOURCE
 #define REAL_TYPE_SIZE_GLOBALISER_SOURCE
 
-#include "../../../variable/type_size/real_type_size.c"
+//
+// Library interface
+//
+
+#include "variable.h"
 
 /**
  * Initialises real type size global variables.
