@@ -19,16 +19,24 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef THREAD_TYPE_SIZE_GLOBALISER_SOURCE
 #define THREAD_TYPE_SIZE_GLOBALISER_SOURCE
 
+//
+// System interface
+//
+
 #include <threads.h> // thrd_t, mtx_t
 
-#include "../../../variable/type_size/thread_type_size.c"
+//
+// Library interface
+//
+
+#include "variable.h"
 
 /**
  * Initialises thread type size global variables.
