@@ -19,22 +19,29 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef PART_HANDLER_SOURCE
 #define PART_HANDLER_SOURCE
 
-#include "../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../controller/handler/element_handler.c"
-#include "../../executor/comparator/integer/greater_or_equal_integer_comparator.c"
-#include "../../executor/comparator/integer/unequal_integer_comparator.c"
-#include "../../executor/copier/integer_copier.c"
-#include "../../logger/logger.c"
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "constant.h"
+#include "controller.h"
+#include "knowledge.h"
+#include "logger.h"
 
 /**
  * Handles the part signal.
