@@ -19,28 +19,26 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef HELPER_SOURCE
 #define HELPER_SOURCE
 
-#include "../constant/format/cyboi/logic_cyboi_format.c"
-#include "../constant/model/character_code/unicode/unicode_character_code_model.c"
-#include "../constant/model/cyboi/help/help_cyboi_model.c"
-#include "../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../constant/model/cyboi/state/state_cyboi_model.c"
-#include "../constant/name/cyboi/state/item_state_cyboi_name.c"
-#include "../constant/name/cyboi/state/primitive_state_cyboi_name.c"
-#include "../constant/type/cyboi/state_cyboi_type.c"
-#include "../executor/copier/array_copier.c"
-#include "../executor/memoriser/allocator/item_allocator.c"
-#include "../executor/memoriser/deallocator/item_deallocator.c"
-#include "../executor/modifier/item_modifier.c"
-#include "../logger/write_logger.c"
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "knowledge.h"
+#include "logger.h"
 
 /**
  * Writes cyboi help message to given output stream.
@@ -49,17 +47,23 @@
  */
 void help(void* p0) {
 
+    //?? fwprintf(stdout, L"Debug: Help. p0: %i\n", p0);
+
     // The message.
     void* m = *NULL_POINTER_STATE_CYBOI_MODEL;
     // The message item data.
     void* md = *NULL_POINTER_STATE_CYBOI_MODEL;
 
+    //
     // Allocate message item.
+    //
     // CAUTION! Due to memory allocation handling, the size MUST NOT
     // be negative or zero, but have at least a value of ONE.
+    //
     // CAUTION! Set size to arbitrary big value, so that message does
     // not have to be reallocated for every character below.
     // This lets the programme possibly run faster.
+    //
     allocate_item((void*) &m, (void*) NUMBER_1024_INTEGER_STATE_CYBOI_MODEL, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
 
     // Append arguments help.
@@ -81,10 +85,13 @@ void help(void* p0) {
     // Append null termination.
     modify_item(m, (void*) NULL_UNICODE_CHARACTER_CODE_MODEL, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE, (void*) FALSE_BOOLEAN_STATE_CYBOI_MODEL, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, *NULL_POINTER_STATE_CYBOI_MODEL, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, (void*) APPEND_MODIFY_LOGIC_CYBOI_FORMAT);
 
+    //
     // Get message item data.
+    //
     // CAUTION! Retrieve data ONLY AFTER having called desired functions!
     // Inside the structure, arrays may have been reallocated,
     // with elements pointing to different memory areas now.
+    //
     copy_array_forward((void*) &md, m, (void*) POINTER_STATE_CYBOI_TYPE, (void*) FALSE_BOOLEAN_STATE_CYBOI_MODEL, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) DATA_ITEM_STATE_CYBOI_NAME);
 
     // Log message.
