@@ -19,23 +19,29 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef LOG_FILE_OPTIONALISER_SOURCE
 #define LOG_FILE_OPTIONALISER_SOURCE
 
-#include <sys/stat.h>
-#include <stdio.h>
+//
+// System interface
+//
 
-#include "../../constant/model/character_code/ascii/ascii_character_code_model.c"
-#include "../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../constant/model/cyboi/state/negative_integer_state_cyboi_model.c"
-#include "../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../executor/converter/encoder/utf/utf_8_encoder.c"
-#include "../../logger/logger.c"
+#include <sys/stat.h> // chmod
+#include <stdio.h> // fopen
+#include <unistd.h> // chown
+
+//
+// Library interface
+//
+
+#include "communication.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
 
 /**
  * Optionalises the log file option.
