@@ -19,26 +19,20 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef TERMINAL_MODE_GETTER_SOURCE
 #define TERMINAL_MODE_GETTER_SOURCE
 
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../logger/logger.c"
+//
+// Library interface
+//
 
-#if defined(__linux__) || defined(__unix__)
-    #include "../../../../executor/accessor/getter/terminal_mode/unix_terminal_mode_getter.c"
-#elif defined(__APPLE__) && defined(__MACH__)
-    #include "../../../../executor/accessor/getter/terminal_mode/unix_terminal_mode_getter.c"
-// Use __CYGWIN__ too, if _WIN32 is not known to mingw.
-#elif defined(_WIN32) || defined(__CYGWIN__)
-    #include "../../../../executor/accessor/getter/terminal_mode/win32_console_mode_getter.c"
-#else
-    #error "Could not compile system. The operating system is not supported. Check out defined preprocessor macros!"
-#endif
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
 
 /**
  * Gets the terminal mode from the device pointed to by the file descriptor.
