@@ -19,23 +19,22 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef DURATION_SETTER_SOURCE
 #define DURATION_SETTER_SOURCE
 
-#include "../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../constant/name/cyboi/state/duration_state_cyboi_name.c"
-#include "../../../executor/calculator/pointer/add_pointer_calculator.c"
-#include "../../../executor/copier/datetime_copier.c"
-#include "../../../executor/copier/pointer_copier.c"
-#include "../../../logger/logger.c"
-#include "../../../variable/type_size/compound_type_size.c"
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
+#include "variable.h"
 
 /**
  * Sets the destination duration's element at the given index.
