@@ -19,16 +19,22 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef INET_SOCKET_ADDRESS_SETTER_SOURCE
 #define INET_SOCKET_ADDRESS_SETTER_SOURCE
 
+//
+// System interface
+//
+
 #if defined(__linux__) || defined(__unix__)
+    #include <netinet/in.h> // struct sockaddr_in
     #include <sys/socket.h>
 #elif defined(__APPLE__) && defined(__MACH__)
+    #include <netinet/in.h> // struct sockaddr_in
     #include <sys/socket.h>
 // Use __CYGWIN__ too, if _WIN32 is not known to mingw.
 #elif defined(_WIN32) || defined(__CYGWIN__)
@@ -37,10 +43,13 @@
     #error "Could not compile system. The operating system is not supported. Check out defined preprocessor macros!"
 #endif
 
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../../logger/logger.c"
-#include "../../../../variable/symbolic_name/address_family_socket_symbolic_name.c"
+//
+// Library interface
+//
+
+#include "constant.h"
+#include "logger.h"
+#include "variable.h"
 
 /**
  * Sets the inet socket address.
