@@ -19,20 +19,28 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef UNIX_TERMINAL_MODE_SETTER_SOURCE
 #define UNIX_TERMINAL_MODE_SETTER_SOURCE
 
-#include <errno.h> // errno
-#include <termios.h> // struct termios, tcsetattr
+//
+// System interface
+//
 
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../../logger/logger.c"
+#include <errno.h> // errno
+#include <stdio.h> // stdout
+#include <termios.h> // struct termios, tcsetattr
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Sets the unix terminal mode into the device pointed to by the file descriptor.
@@ -84,7 +92,7 @@ void set_unix_terminal_mode(void* p0, void* p1) {
 
                 log_message_terminated((void*) ERROR_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not set unix terminal mode. An error occured.");
                 fwprintf(stdout, L"Error: Could not set unix terminal mode. An error occured. r: %i\n", r);
-                log_errno((void*) &errno);
+                log_error((void*) &errno);
             }
 
         } else {
