@@ -19,21 +19,29 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef BSD_SOCKET_ENABLER_SOURCE
 #define BSD_SOCKET_ENABLER_SOURCE
 
+//
+// System interface
+//
+
 #include <sys/socket.h> // accept
 #include <errno.h> // errno
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
 
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../../executor/copier/integer_copier.c"
-#include "../../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
 
 /**
  * Accepts client request on the given bsd socket.
@@ -98,7 +106,7 @@ void enable_bsd_socket(void* p0, void* p1) {
 
             log_message_terminated((void*) ERROR_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not enable bsd socket. An error occured.");
             fwprintf(stdout, L"Error: Could not enable bsd socket. An error occured. c: %i\n", c);
-            log_errno((void*) &errno);
+            log_error((void*) &errno);
         }
 
     } else {
