@@ -19,22 +19,28 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef AWAKENER_SOURCE
 #define AWAKENER_SOURCE
 
-#include "../../constant/channel/cyboi/cyboi_channel.c"
-#include "../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../executor/awakener/display_awakener.c"
-#include "../../executor/awakener/serial_port_awakener.c"
-#include "../../executor/awakener/socket_awakener.c"
-#include "../../executor/awakener/terminal_awakener.c"
-#include "../../executor/comparator/integer/equal_integer_comparator.c"
-#include "../../logger/logger.c"
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
+#include "server.h"
 
 /**
  * Let the system send an input to itself over the channel
