@@ -19,25 +19,21 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef CALCULATOR_SOURCE
 #define CALCULATOR_SOURCE
 
-#include "../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../executor/calculator/character_calculator.c"
-#include "../../executor/calculator/complex_calculator.c"
-#include "../../executor/calculator/double_calculator.c"
-#include "../../executor/calculator/fraction_calculator.c"
-#include "../../executor/calculator/integer_calculator.c"
-#include "../../executor/calculator/pointer_calculator.c"
-#include "../../executor/comparator/integer/equal_integer_comparator.c"
-#include "../../executor/memoriser/offset_adder.c"
-#include "../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
 
 //
 // Models of type "complex" or "fraction" are not
