@@ -19,18 +19,27 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef CARTESIAN_POLAR_COMPLEX_CALCULATOR_SOURCE
 #define CARTESIAN_POLAR_COMPLEX_CALCULATOR_SOURCE
 
-#include <math.h> // M_PI, sqrt, atan, abs
+//
+// System interface
+//
 
-#include "../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../logger/logger.c"
+#include <math.h> // M_PI, sqrt, atan, abs
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Transforms a complex number from cartesian into polar coordinates.
