@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Falk Müller <falk89@web.de>
  * @author Christian Heller <christian.heller@cybop.org>
  */
@@ -27,11 +27,18 @@
 #ifndef POWER_DOUBLE_CALCULATOR_SOURCE
 #define POWER_DOUBLE_CALCULATOR_SOURCE
 
+//
+// System interface
+//
+
 #include <math.h> // pow
 
-#include "../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Calculates the value of the base raised to the power of the given value.
