@@ -19,18 +19,24 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef ABSOLUTE_INTEGER_CALCULATOR_SOURCE
 #define ABSOLUTE_INTEGER_CALCULATOR_SOURCE
 
+//
+// System interface
+//
+
 #include <stdlib.h>
 
-#include "../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "logger.h"
 
 /**
  * Determines the absolute value of the source and stores it in destination.
