@@ -19,17 +19,19 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef MODULO_INTEGER_CALCULATOR_SOURCE
 #define MODULO_INTEGER_CALCULATOR_SOURCE
 
-#include "../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Determines the remainder of dividing the dividend by the divisor integer.
