@@ -19,20 +19,27 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef OPERATION_CHECKER_SOURCE
 #define OPERATION_CHECKER_SOURCE
 
-#include "../../constant/format/cyboi/logic_cyboi_format.c"
-#include "../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../executor/checker/array_checker.c"
-#include "../../executor/comparator/integer/equal_integer_comparator.c"
-#include "../../logger/logger.c"
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Checks two arrays lexicographically.
@@ -118,6 +125,8 @@ void check_operation(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
         log_message_terminated((void*) WARNING_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not check operation. The operation type is unknown.");
+        fwprintf(stdout, L"Warning: Could not check operation. The operation type is unknown. p5: %i\n", p5);
+        fwprintf(stdout, L"Warning: Could not check operation. The operation type is unknown. *p5: %i\n", *((int*) p5));
     }
 }
 
