@@ -19,19 +19,16 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef FIND_COMMAND_COMMANDER_SOURCE
 #define FIND_COMMAND_COMMANDER_SOURCE
 
-#include "../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../executor/commander/adapt_unix_to_windows_path_commander.c"
-#include "../../executor/memoriser/allocator/item_allocator.c"
-#include "../../executor/runner/executor.c"
+//
+// System interface
+//
 
 //
 // CAUTION! The options of many commands are SIMILAR on various platforms.
@@ -44,23 +41,24 @@
 // Therefore, it makes sense to distinguish between platforms
 // at EVERY option, even if that produces some redundant code.
 //
-
 #if defined(__linux__) || defined(__unix__)
-    #include "../../constant/model/command/unix_command_model.c"
-    #include "../../constant/name/command_option/unix/find_command_unix_command_option_name.c"
 #elif defined(__APPLE__) && defined(__MACH__)
-    #include "../../constant/model/command/unix_command_model.c"
-    #include "../../constant/name/command_option/unix/find_command_unix_command_option_name.c"
 // Use __CYGWIN__ too, if _WIN32 is not known to mingw.
 #elif defined(_WIN32) || defined(__CYGWIN__)
-    #include "../../constant/model/command/win32_command_model.c"
 #else
     #error "Could not compile system. The operating system is not supported. Check out defined preprocessor macros!"
 #endif
 
-#ifndef _MSC_VER
-    #include <unistd.h>
-#endif
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
+#include "shell.h"
+#include "system.h"
 
 /**
  * Displays information on a command.
