@@ -19,26 +19,28 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef RECEIVER_SOURCE
 #define RECEIVER_SOURCE
 
-#include "../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../../executor/communicator/receiver/decode_receiver.c"
-#include "../../../executor/communicator/receiver/deserialise_receiver.c"
-//?? #include "../../../executor/communicator/receiver/extract_receiver.c"
-#include "../../../executor/communicator/receiver/read_receiver.c"
-#include "../../../executor/communicator/receiver/select_receiver.c"
-#include "../../../executor/memoriser/allocator/item_allocator.c"
-#include "../../../executor/memoriser/deallocator/item_deallocator.c"
-#include "../../../executor/streamer/reader/deallocation_reader.c"
-#include "../../../logger/logger.c"
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "communication.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
 
 /**
  * Receives a message via the given channel.
