@@ -19,24 +19,20 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef CHARACTER_COMPARATOR_SOURCE
 #define CHARACTER_COMPARATOR_SOURCE
 
-#include "../../constant/format/cyboi/logic_cyboi_format.c"
-#include "../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../executor/comparator/character/equal_character_comparator.c"
-#include "../../executor/comparator/character/greater_character_comparator.c"
-#include "../../executor/comparator/character/greater_or_equal_character_comparator.c"
-#include "../../executor/comparator/character/less_character_comparator.c"
-#include "../../executor/comparator/character/less_or_equal_character_comparator.c"
-#include "../../executor/comparator/character/unequal_character_comparator.c"
-#include "../../executor/comparator/integer/equal_integer_comparator.c"
-#include "../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Compares the left- with the right character.
