@@ -19,19 +19,20 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef LESS_OR_EQUAL_FRACTION_COMPARATOR_SOURCE
 #define LESS_OR_EQUAL_FRACTION_COMPARATOR_SOURCE
 
-#include "../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../constant/name/cyboi/state/fraction_state_cyboi_name.c"
-#include "../../../executor/calculator/integer/multiply_integer_calculator.c"
-#include "../../../executor/copier/array_copier.c"
-#include "../../../executor/copier/fraction_copier.c"
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "constant.h"
+#include "knowledge.h"
 
 /**
  * Compares the left- with the right double for lessness and equality.
