@@ -19,16 +19,19 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef GREATER_WIDE_CHARACTER_COMPARATOR_SOURCE
 #define GREATER_WIDE_CHARACTER_COMPARATOR_SOURCE
 
-#include "../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../executor/copier/integer_copier.c"
+//
+// Library interface
+//
+
+#include "constant.h"
+#include "knowledge.h"
 
 /**
  * Compares the left- with the right wide character for greaterness.
