@@ -19,20 +19,28 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef INITIALISER_SOURCE
 #define INITIALISER_SOURCE
 
-#include "../../../constant/channel/cyboi/cyboi_channel.c"
-#include "../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../executor/comparator/integer/equal_integer_comparator.c"
-#include "../../../executor/configurator/initialiser/serial_port/serial_port_initialiser.c"
-#include "../../../executor/configurator/initialiser/terminal/terminal_initialiser.c"
-#include "../../../logger/logger.c"
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "client.h"
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Initialises the device belonging to the given channel.
