@@ -19,22 +19,20 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef INTEGER_CONTAINER_SOURCE
 #define INTEGER_CONTAINER_SOURCE
 
-#include "../../../constant/format/cyboi/logic_cyboi_format.c"
-#include "../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../executor/container/basic/integer/both_integer_container.c"
-#include "../../../executor/container/basic/integer/left_integer_container.c"
-#include "../../../executor/container/basic/integer/none_integer_container.c"
-#include "../../../executor/container/basic/integer/right_integer_container.c"
-#include "../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "algorithm.h"
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Compares if the bounded area contains the value.
@@ -53,6 +51,7 @@ void contain_integer(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
         log_message_terminated((void*) DEBUG_LEVEL_LOG_CYBOI_MODEL, (void*) L"Contain integer.");
 
+/*??
         // The comparison result.
         int r = *FALSE_BOOLEAN_STATE_CYBOI_MODEL;
 
@@ -100,6 +99,7 @@ void contain_integer(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
             log_message_terminated((void*) WARNING_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not contain integer. The operation type is unknown.");
         }
+*/
 
     } else {
 
