@@ -19,20 +19,28 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef CHARACTER_ISO_8859_DECODER_SOURCE
 #define CHARACTER_ISO_8859_DECODER_SOURCE
 
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../../executor/comparator/integer/less_integer_comparator.c"
-#include "../../../../executor/converter/decoder/ascii/ascii_decoder.c"
-#include "../../../../executor/converter/decoder/iso_8859/extension_iso_8859_decoder.c"
-#include "../../../../logger/logger.c"
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "communication.h"
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Decodes the iso-8859 character into a utf-32 wide character.
