@@ -19,20 +19,21 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef EXTENSION_ISO_8859_DECODER_SOURCE
 #define EXTENSION_ISO_8859_DECODER_SOURCE
 
-#include "../../../../constant/encoding/cyboi/cyboi_encoding.c"
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../../executor/comparator/integer/equal_integer_comparator.c"
-#include "../../../../executor/converter/decoder/iso_8859/iso_8859_1_decoder.c"
-#include "../../../../executor/converter/decoder/iso_8859/iso_8859_15_decoder.c"
-#include "../../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "communication.h"
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Decodes the iso-8859 extension character data into utf-32 wide character data.
