@@ -19,36 +19,26 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef UTF_8_ENCODER_SOURCE
 #define UTF_8_ENCODER_SOURCE
 
-#include <errno.h> // errno
+//
+// System interface
+//
 
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/state_cyboi_model.c"
-#include "../../../../constant/name/cyboi/state/item_state_cyboi_name.c"
-#include "../../../../constant/name/cyboi/state/primitive_state_cyboi_name.c"
-#include "../../../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../../../executor/calculator/integer/add_integer_calculator.c"
-#include "../../../../executor/calculator/integer/multiply_integer_calculator.c"
-#include "../../../../executor/copier/array_copier.c"
-#include "../../../../executor/copier/integer_copier.c"
-#include "../../../../executor/memoriser/reallocator/item_reallocator.c"
-#include "../../../../logger/logger.c"
+#include <errno.h> // errno
+#include <stdio.h> // stdout
 
 #if defined(__linux__) || defined(__unix__)
     #include <locale.h> // setlocale
-    #include <wchar.h> // wcsnrtombs
+    #include <wchar.h> // wcsnrtombs, fwprintf
 #elif defined(__APPLE__) && defined(__MACH__)
     #include <locale.h> // setlocale
-    #include <wchar.h> // wcsnrtombs
+    #include <wchar.h> // wcsnrtombs, fwprintf
 // Use __CYGWIN__ too, if _WIN32 is not known to mingw.
 #elif defined(_WIN32) || defined(__CYGWIN__)
     #include <windows.h>
@@ -56,6 +46,15 @@
     #error "Could not compile system. The operating system is not supported. Check out defined preprocessor macros!"
 #endif
 
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
+
 //
 // Reflexions on character set conversion.
 //
@@ -370,7 +369,7 @@ void encode_utf_8(void* p0, void* p1, void* p2) {
 
                     log_message_terminated((void*) ERROR_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not encode utf-8. An error occured.");
                     fwprintf(stdout, L"Error: Could not encode utf-8. An error occured. n: %i\n", n);
-                    log_errno((void*) &errno);
+                    log_error((void*) &errno);
                 }
 
             } else {
