@@ -19,21 +19,20 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef DURATION_COPIER_SOURCE
 #define DURATION_COPIER_SOURCE
 
-#include "../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../constant/name/cyboi/state/duration_state_cyboi_name.c"
-#include "../../executor/accessor/getter/duration_getter.c"
-#include "../../executor/accessor/setter/duration_setter.c"
-#include "../../executor/memoriser/allocator/array_allocator.c"
-#include "../../executor/memoriser/deallocator/array_deallocator.c"
-#include "../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
 
 /**
  * Copies the duration.
