@@ -19,26 +19,20 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef PIPE_CLOSER_SOURCE
 #define PIPE_CLOSER_SOURCE
 
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../logger/logger.c"
+//
+// Library interface
+//
 
-#if defined(__linux__) || defined(__unix__)
-    #include "../../../../executor/dispatcher/closer/unix_pipe/unix_pipe_closer.c"
-#elif defined(__APPLE__) && defined(__MACH__)
-    #include "../../../../executor/dispatcher/closer/unix_pipe/unix_pipe_closer.c"
-// Use __CYGWIN__ too, if _WIN32 is not known to mingw.
-#elif defined(_WIN32) || defined(__CYGWIN__)
-    #include "../../../../executor/dispatcher/closer/win32_pipe/win32_pipe_closer.c"
-#else
-    #error "Could not compile system. The operating system is not supported. Check out defined preprocessor macros!"
-#endif
+#include "client.h"
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Closes down a pipeline (pipe), also called "anonymous pipe".
