@@ -19,23 +19,28 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef FLAG_OPENER_SOURCE
 #define FLAG_OPENER_SOURCE
 
-#include "../../../constant/channel/cyboi/cyboi_channel.c"
-#include "../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../executor/comparator/integer/equal_integer_comparator.c"
-#include "../../../executor/comparator/integer/unequal_integer_comparator.c"
-#include "../../../executor/configurator/initialiser/initialiser.c"
-#include "../../../executor/dispatcher/opener/device_opener.c"
-#include "../../../executor/dispatcher/opener/stub_opener.c"
-#include "../../../executor/logifier/boolean/and_boolean_logifier.c"
-#include "../../../logger/logger.c"
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "client.h"
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Opens a client either as standalone device or from request buffer, depending on the given server flag.
