@@ -19,27 +19,29 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef OPENER_SOURCE
 #define OPENER_SOURCE
 
-#include "../../../constant/format/cyboi/logic_cyboi_format.c"
-#include "../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/state_cyboi_model.c"
-#include "../../../constant/name/cyboi/state/primitive_state_cyboi_name.c"
-#include "../../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../../executor/dispatcher/opener/entry_opener.c"
-#include "../../../executor/dispatcher/opener/flag_opener.c"
-#include "../../../executor/dispatcher/opener/identification_opener.c"
-#include "../../../executor/finder/mode_finder.c"
-#include "../../../executor/memoriser/allocator/client_entry_allocator.c"
-#include "../../../executor/modifier/item_modifier.c"
-#include "../../../logger/logger.c"
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "algorithm.h"
+#include "client.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
 
 /**
  * Opens a new client belonging to the given channel.
