@@ -19,19 +19,27 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef SERIAL_PORT_OPENER_SOURCE
 #define SERIAL_PORT_OPENER_SOURCE
 
+//
+// System interface
+//
+
 #include <fcntl.h> // O_RDWR, O_NOCTTY
 #include <sys/stat.h> // mode_t, S_IRWXU
 
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../executor/dispatcher/opener/basic/basic_opener.c"
-#include "../../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "client.h"
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Opens the serial port with the given filename.
