@@ -19,26 +19,27 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef CONNEXION_SOCKET_OPENER_SOURCE
 #define CONNEXION_SOCKET_OPENER_SOURCE
 
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../logger/logger.c"
+//
+// System interface
+//
 
-#if defined(__linux__) || defined(__unix__)
-    #include "../../../../executor/dispatcher/opener/bsd_socket/connexion_bsd_socket_opener.c"
-#elif defined(__APPLE__) && defined(__MACH__)
-    #include "../../../../executor/dispatcher/opener/bsd_socket/connexion_bsd_socket_opener.c"
-// Use __CYGWIN__ too, if _WIN32 is not known to mingw.
-#elif defined(_WIN32) || defined(__CYGWIN__)
-    #include "../../../../executor/dispatcher/opener/winsock/connexion_winsock_opener.c"
-#else
-    #error "Could not compile system. The operating system is not supported. Check out defined preprocessor macros!"
-#endif
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "client.h"
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Connects the socket to the server given by the address.
