@@ -19,29 +19,24 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef SOCKET_OPENER_SOURCE
 #define SOCKET_OPENER_SOURCE
 
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../../executor/dispatcher/opener/socket/connexion_socket_opener.c"
-#include "../../../../executor/dispatcher/opener/socket/device_socket_opener.c"
-#include "../../../../executor/memoriser/allocator/socket_address/socket_address_allocator.c"
-#include "../../../../executor/memoriser/deallocator/socket_address_deallocator.c"
-#include "../../../../executor/representer/deserialiser/socket/address_family_socket_deserialiser.c"
-#include "../../../../executor/representer/deserialiser/socket/protocol_family_socket_deserialiser.c"
-#include "../../../../executor/representer/deserialiser/socket/protocol_socket_deserialiser.c"
-#include "../../../../executor/representer/deserialiser/socket/style_socket_deserialiser.c"
-#include "../../../../logger/logger.c"
-#include "../../../../variable/symbolic_name/address_family_socket_symbolic_name.c"
-#include "../../../../variable/symbolic_name/protocol_family_socket_symbolic_name.c"
-#include "../../../../variable/symbolic_name/protocol_socket_symbolic_name.c"
-#include "../../../../variable/symbolic_name/style_socket_symbolic_name.c"
+//
+// Library interface
+//
+
+#include "client.h"
+#include "communication.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
+#include "variable.h"
+#include "web.h"
 
 /**
  * Connects the given socket to the server given by the address.
