@@ -19,32 +19,30 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef FILE_UNIX_FIFO_OPENER_SOURCE
 #define FILE_UNIX_FIFO_OPENER_SOURCE
 
+//
+// System interface
+//
+
 #include <sys/stat.h> // mode_t, mkfifo
 #include <errno.h> // errno
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
 
-#include "../../../../constant/format/cyboi/logic_cyboi_format.c"
-#include "../../../../constant/model/character_code/ascii/ascii_character_code_model.c"
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/state_cyboi_model.c"
-#include "../../../../constant/name/cyboi/state/item_state_cyboi_name.c"
-#include "../../../../constant/name/cyboi/state/primitive_state_cyboi_name.c"
-#include "../../../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../../../executor/converter/encoder/utf/utf_8_encoder.c"
-#include "../../../../executor/copier/array_copier.c"
-#include "../../../../executor/memoriser/allocator/item_allocator.c"
-#include "../../../../executor/memoriser/deallocator/item_deallocator.c"
-#include "../../../../executor/modifier/item_modifier.c"
-#include "../../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "communication.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
 
 /**
  * Creates a unix fifo special file in the filesystem.
@@ -123,7 +121,7 @@ void open_unix_fifo_file(void* p0, void* p1, void* p2) {
 
             log_message_terminated((void*) ERROR_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not open unix fifo file. An error occured.");
             fwprintf(stdout, L"Error: Could not open unix fifo file. An error occured. %i\n", r);
-            log_errno((void*) &errno);
+            log_error((void*) &errno);
         }
 
         // Deallocate terminated file name item.
