@@ -19,20 +19,29 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef UNIX_FIFO_OPENER_SOURCE
 #define UNIX_FIFO_OPENER_SOURCE
 
+//
+// System interface
+//
+
 #include <sys/stat.h> // mode_t, S_IRWXU
 #include <fcntl.h> // O_RDWR, O_NOCTTY
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
 
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../executor/dispatcher/opener/basic/basic_opener.c"
-#include "../../../../executor/dispatcher/opener/unix_fifo/file_unix_fifo_opener.c"
-#include "../../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "client.h"
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Makes a unix first-in-first-out (fifo), also called "named pipeline" (named pipe).
