@@ -19,20 +19,28 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef UNIX_PIPE_OPENER_SOURCE
 #define UNIX_PIPE_OPENER_SOURCE
 
-#include <unistd.h> // pipe
-#include <errno.h> // errno
+//
+// System interface
+//
 
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../../logger/logger.c"
+#include <errno.h> // errno
+#include <stdio.h> // stdout
+#include <unistd.h> // pipe
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Opens up a unix pipeline (pipe), also called "anonymous pipe".
@@ -74,7 +82,7 @@ void open_unix_pipe(void* p0) {
 
             log_message_terminated((void*) ERROR_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not open unix pipe. An error occured.");
             fwprintf(stdout, L"Error: Could not open unix pipe. An error occured. %i\n", r);
-            log_errno((void*) &errno);
+            log_error((void*) &errno);
         }
 
     } else {
