@@ -19,26 +19,20 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef INTEGER_LOGIFIER_SOURCE
 #define INTEGER_LOGIFIER_SOURCE
 
-#include "../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../constant/format/cyboi/logic_cyboi_format.c"
-#include "../../executor/logifier/integer/and_integer_logifier.c"
-#include "../../executor/logifier/integer/not_integer_logifier.c"
-#include "../../executor/logifier/integer/or_integer_logifier.c"
-#include "../../executor/logifier/integer/nor_integer_logifier.c"
-#include "../../executor/logifier/integer/xnor_integer_logifier.c"
-#include "../../executor/logifier/integer/nand_integer_logifier.c"
-#include "../../executor/logifier/integer/xor_integer_logifier.c"
-#include "../../executor/logifier/integer/neg_integer_logifier.c"
-#include "../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Connects the given values following the given integer bitwise logic operation.
