@@ -19,26 +19,20 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef BIND_SOCKET_STARTER_SOURCE
 #define BIND_SOCKET_STARTER_SOURCE
 
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../logger/logger.c"
+//
+// Library interface
+//
 
-#if defined(__linux__) || defined(__unix__)
-    #include "../../../../executor/maintainer/starter/bsd_socket/bind_bsd_socket_starter.c"
-#elif defined(__APPLE__) && defined(__MACH__)
-    #include "../../../../executor/maintainer/starter/bsd_socket/bind_bsd_socket_starter.c"
-// Use __CYGWIN__ too, if _WIN32 is not known to mingw.
-#elif defined(_WIN32) || defined(__CYGWIN__)
-    #include "../../../../executor/maintainer/starter/winsock/bind_winsock_starter.c"
-#else
-    #error "Could not compile system. The operating system is not supported. Check out defined preprocessor macros!"
-#endif
+#include "constant.h"
+#include "logger.h"
+#include "server.h"
 
 /**
  * Binds the address to the socket.
