@@ -19,31 +19,30 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef STARTER_SOURCE
 #define STARTER_SOURCE
 
-#include "../../../constant/format/cyboi/logic_cyboi_format.c"
-#include "../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/negative_integer_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/state_cyboi_model.c"
-#include "../../../constant/name/cyboi/state/input_output_state_cyboi_name.c"
-#include "../../../constant/name/cyboi/state/primitive_state_cyboi_name.c"
-#include "../../../constant/name/cyboi/state/server_state_cyboi_name.c"
-#include "../../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../../executor/copier/array_copier.c"
-#include "../../../executor/finder/list_finder.c"
-#include "../../../executor/maintainer/starter/entry_starter.c"
-#include "../../../executor/maintainer/starter/service_starter.c"
-#include "../../../executor/memoriser/allocator/server_entry_allocator.c"
-#include "../../../executor/modifier/item_modifier.c"
-#include "../../../logger/logger.c"
-#include "../../../mapper/channel_to_internal_memory_mapper.c"
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "algorithm.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
+#include "mapper.h"
+#include "server.h"
 
 /**
  * Starts up the given server.
