@@ -19,26 +19,20 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef CHARACTER_MANIPULATOR_SOURCE
 #define CHARACTER_MANIPULATOR_SOURCE
 
-#include "../../constant/format/cyboi/logic_cyboi_format.c"
-#include "../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../executor/manipulator/character/check_character_manipulator.c"
-#include "../../executor/manipulator/character/clear_character_manipulator.c"
-#include "../../executor/manipulator/character/rotate_left_character_manipulator.c"
-#include "../../executor/manipulator/character/rotate_right_character_manipulator.c"
-#include "../../executor/manipulator/character/set_character_manipulator.c"
-#include "../../executor/manipulator/character/shift_left_character_manipulator.c"
-#include "../../executor/manipulator/character/shift_right_character_manipulator.c"
-#include "../../executor/manipulator/character/toggle_character_manipulator.c"
-#include "../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Manipulates the character value bit at the given position.
