@@ -19,19 +19,20 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef CHECK_INTEGER_MANIPULATOR_SOURCE
 #define CHECK_INTEGER_MANIPULATOR_SOURCE
 
-#include "../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../executor/logifier/integer/and_integer_logifier.c"
-#include "../../../executor/manipulator/integer/shift_left_integer_manipulator.c"
-#include "../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Checks (in other words: gets) the bit at the given position.
