@@ -19,25 +19,21 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef ROTATE_RIGHT_INTEGER_MANIPULATOR_SOURCE
 #define ROTATE_RIGHT_INTEGER_MANIPULATOR_SOURCE
 
-#include "../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../executor/calculator/integer/multiply_integer_calculator.c"
-#include "../../../executor/calculator/integer/subtract_integer_calculator.c"
-#include "../../../executor/manipulator/integer/check_integer_manipulator.c"
-#include "../../../executor/manipulator/integer/clear_integer_manipulator.c"
-#include "../../../executor/manipulator/integer/set_integer_manipulator.c"
-#include "../../../executor/manipulator/integer/shift_right_integer_manipulator.c"
-#include "../../../logger/logger.c"
-#include "../../../mapper/type_to_size_mapper.c"
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "constant.h"
+#include "logger.h"
+#include "mapper.h"
 
 /**
  * Rotates all bits of value to the right by position.
