@@ -19,22 +19,29 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef MUTEX_ALLOCATOR_SOURCE
 #define MUTEX_ALLOCATOR_SOURCE
 
-#include <threads.h> // mtx_t, mtx_init, thrd_error
+//
+// System interface
+//
 
-#include "../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/state_cyboi_model.c"
-#include "../../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../../executor/memoriser/allocator/array_allocator.c"
-#include "../../../logger/logger.c"
-#include "../../../variable/symbolic_name/mutex_thread_symbolic_name.c"
+#include <threads.h> // mtx_t, mtx_init, thrd_error
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
+#include "variable.h"
 
 /**
  * Allocates the mutex.
@@ -59,17 +66,25 @@ void allocate_mutex(void* p0) {
         //
         allocate_array(p0, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) MUTEX_THREAD_STATE_CYBOI_TYPE);
 
-        // Cast mutex to correct type.
-        mtx_t* t = (mtx_t*) *m;
+        if (*m != *NULL_POINTER_STATE_CYBOI_MODEL) {
 
-        // Initialise mutex.
-        int r = mtx_init(t, *PLAIN_MUTEX_TYPE_THREAD_SYMBOLIC_NAME);
+            // Cast mutex to correct type.
+            mtx_t* t = (mtx_t*) *m;
 
-        // Evaluate mutex object creation result.
-        if (r == thrd_error) {
+            // Initialise mutex.
+            int r = mtx_init(t, *PLAIN_MUTEX_TYPE_THREAD_SYMBOLIC_NAME);
 
-            log_message_terminated((void*) ERROR_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not allocate mutex. The mutex object creation failed.");
-            fwprintf(stdout, L"Error: Could not allocate mutex. The mutex object creation failed. mr: %i\n", r);
+            // Evaluate mutex object creation result.
+            if (r == thrd_error) {
+
+                log_message_terminated((void*) ERROR_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not allocate mutex. The mutex object creation failed.");
+                fwprintf(stdout, L"Error: Could not allocate mutex. The mutex object creation failed. mr: %i\n", r);
+            }
+
+        } else {
+
+            log_message_terminated((void*) ERROR_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not allocate mutex. The dereferenced mutex is null.");
+            fwprintf(stdout, L"Error: Could not allocate mutex. The dereferenced mutex is null. *m: %i\n", *m);
         }
 
     } else {
