@@ -19,39 +19,44 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef PART_ALLOCATOR_SOURCE
 #define PART_ALLOCATOR_SOURCE
 
-#include "../../../constant/format/cyboi/logic_cyboi_format.c"
-#include "../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/state_cyboi_model.c"
-#include "../../../constant/name/cyboi/state/part_state_cyboi_name.c"
-#include "../../../constant/name/cyboi/state/primitive_state_cyboi_name.c"
-#include "../../../constant/type/cyboi/state_cyboi_type.c"
 //
-// CAUTION! Do NOT include this file in order to avoid circular references.
-// Use a forward declaration instead below.
+// System interface
 //
-// #include "../../../executor/copier/array_copier.c"
-#include "../../../executor/memoriser/allocator/array_allocator.c"
-#include "../../../executor/memoriser/allocator/item_allocator.c"
-//
-// CAUTION! Do NOT include this file in order to avoid circular references.
-// Use a forward declaration instead below.
-//
-// #include "../../../executor/modifier/item_modifier.c"
-#include "../../../logger/logger.c"
-#include "../../../variable/reference_counter.c"
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
 
 //
-// Forward declaration.
+// Library interface
+//
+
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
+#include "variable.h"
+
+//
+// Forbidden interface
+//
+// CAUTION! Do NOT include the following files since otherwise,
+// circular references would occur due to module dependencies.
+// Instead, forward declarations are used further below.
+// Therefore, the following includes are to be commented OUT
+// and listed here just for information.
+//
+
+// #include "../../../executor/copier/array/forward_array_copier.c"
+// #include "../../../executor/modifier/item_modifier.c"
+
+//
+// Forward declaration
 //
 
 void copy_array_forward(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6);
