@@ -19,14 +19,20 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef INET_SOCKET_ADDRESS_ALLOCATOR_SOURCE
 #define INET_SOCKET_ADDRESS_ALLOCATOR_SOURCE
 
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
 #include <string.h> // memset
+#include <wchar.h> // fwprintf
 
 #if defined(__linux__) || defined(__unix__)
     #include <netinet/in.h> // struct in_addr
@@ -39,17 +45,15 @@
     #error "Could not compile system. The operating system is not supported. Check out defined preprocessor macros!"
 #endif
 
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/state_cyboi_model.c"
-#include "../../../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../../../executor/accessor/setter/socket_address/inet_socket_address_setter.c"
-#include "../../../../executor/copier/integer_copier.c"
-#include "../../../../executor/memoriser/allocator/array_allocator.c"
-#include "../../../../executor/representer/deserialiser/host_address/inet_host_address_deserialiser.c"
-#include "../../../../logger/logger.c"
-#include "../../../../variable/type_size/socket_type_size.c"
+//
+// Library interface
+//
+
+#include "communication.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
+#include "variable.h"
 
 /**
  * Allocate inet socket address.
