@@ -19,20 +19,21 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef INSERTER_SOURCE
 #define INSERTER_SOURCE
 
-#include "../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../executor/comparator/integer/greater_or_equal_integer_comparator.c"
-#include "../../../executor/comparator/integer/less_integer_comparator.c"
-#include "../../../executor/modifier/inserter/inside_inserter.c"
-#include "../../../executor/modifier/overwriter/overwriter.c"
-#include "../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
 
 /**
  * Inserts the source- into the destination array, starting from the index.
