@@ -19,19 +19,18 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef COMPRESSOR_SOURCE
 #define COMPRESSOR_SOURCE
 
-#include "../../constant/compression/cyboi/cyboi_compression.c"
-#include "../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../executor/packer/compressor/gzip/gzip_compressor.c"
-#include "../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "logger.h"
 
 /**
  * Compress the source into the destination, according to the given compression.
