@@ -19,26 +19,22 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef BASIC_JD_DATETIME_DESERIALISER_SOURCE
 #define BASIC_JD_DATETIME_DESERIALISER_SOURCE
 
-#include "../../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../../constant/model/cyboi/state/double_state_cyboi_model.c"
-#include "../../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../../../constant/name/cyboi/state/primitive_state_cyboi_name.c"
-#include "../../../../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../../../../executor/calculator/double/add_double_calculator.c"
-#include "../../../../../executor/memoriser/allocator/array_allocator.c"
-#include "../../../../../executor/memoriser/deallocator/array_deallocator.c"
-#include "../../../../../executor/modifier/item_modifier.c"
-#include "../../../../../executor/representer/deserialiser/numeral/numeral_deserialiser.c"
-#include "../../../../../executor/representer/deserialiser/time_scale/julian_date/julian_date_time_scale_deserialiser.c"
-#include "../../../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "communication.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
 
 /**
  * Deserialises the source jd/mjd/tjd wide character data into the destination datetime item.
