@@ -19,29 +19,29 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef CONTENT_GUI_DESERIALISER_SOURCE
 #define CONTENT_GUI_DESERIALISER_SOURCE
 
-#include "../../../../constant/format/cyboi/logic_cyboi_format.c"
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../../constant/model/cybol/xcb/event_xcb_cybol_model.c"
-#include "../../../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../../../executor/checker/operation_checker.c"
-#include "../../../../executor/representer/deserialiser/gui_action/button_press_gui_action_deserialiser.c"
-#include "../../../../executor/representer/deserialiser/gui_action/button_release_gui_action_deserialiser.c"
-#include "../../../../executor/representer/deserialiser/gui_action/close_window_gui_action_deserialiser.c"
-#include "../../../../executor/representer/deserialiser/gui_action/enter_notify_gui_action_deserialiser.c"
-#include "../../../../executor/representer/deserialiser/gui_action/expose_gui_action_deserialiser.c"
-#include "../../../../executor/representer/deserialiser/gui_action/key_press_gui_action_deserialiser.c"
-#include "../../../../executor/representer/deserialiser/gui_action/key_release_gui_action_deserialiser.c"
-#include "../../../../executor/representer/deserialiser/gui_action/leave_notify_gui_action_deserialiser.c"
-#include "../../../../executor/representer/deserialiser/gui_action/motion_notify_gui_action_deserialiser.c"
-#include "../../../../logger/logger.c"
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "communication.h"
+#include "constant.h"
+#include "gui.h"
+#include "logger.h"
 
 /**
  * Deserialises the gui content into an action.
