@@ -19,13 +19,17 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef INET_HOST_ADDRESS_DESERIALISER_SOURCE
 #define INET_HOST_ADDRESS_DESERIALISER_SOURCE
 
+//
+// System interface
+//
+
 #include <stdint.h> // uint32_t
 
 #if defined(__linux__) || defined(__unix__)
@@ -42,21 +46,17 @@
     #error "Could not compile system. The operating system is not supported. Check out defined preprocessor macros!"
 #endif
 
-#include "../../../../constant/format/cyboi/logic_cyboi_format.c"
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../../constant/model/cybol/socket/address_socket_cybol_model.c"
-#include "../../../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../../../executor/checker/operation_checker.c"
-#include "../../../../executor/converter/encoder/utf/utf_8_encoder.c"
-#include "../../../../executor/copier/array_copier.c"
-#include "../../../../executor/memoriser/allocator/item_allocator.c"
-#include "../../../../executor/memoriser/deallocator/item_deallocator.c"
-#include "../../../../executor/modifier/item_modifier.c"
-#include "../../../../logger/logger.c"
-#include "../../../../variable/symbolic_name/address_family_socket_symbolic_name.c"
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "communication.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
+#include "variable.h"
+#include "web.h"
 
 /**
  * Deserialises inet host address.
