@@ -19,14 +19,18 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef HTTP_RESPONSE_DESERIALISER_SOURCE
 #define HTTP_RESPONSE_DESERIALISER_SOURCE
 
-#include "../../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "logger.h"
 
 //
 // Many Web servers supply incorrect Content-Type headers with their
@@ -54,8 +58,6 @@
 void deserialise_http_response(void* p0, void* p1, void* p2, void* p3) {
 
     log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Deserialise http response.");
-
-//??    deserialise_http_response_??(p0, p1, p2, p3, p4, p5, (void*) &p6, p7);
 }
 
 /* HTTP_RESPONSE_DESERIALISER_SOURCE */
