@@ -19,25 +19,22 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef JULIAN_DAY_GREGORIAN_CALENDAR_TIME_SCALE_DESERIALISER_SOURCE
 #define JULIAN_DAY_GREGORIAN_CALENDAR_TIME_SCALE_DESERIALISER_SOURCE
 
-#include "../../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../../../constant/model/time_scale/calendar_time_scale_model.c"
-#include "../../../../../constant/model/time_scale/julian_date_time_scale_model.c"
-#include "../../../../../executor/calculator/integer/add_integer_calculator.c"
-#include "../../../../../executor/calculator/integer/divide_integer_calculator.c"
-#include "../../../../../executor/calculator/integer/modulo_integer_calculator.c"
-#include "../../../../../executor/calculator/integer/multiply_integer_calculator.c"
-#include "../../../../../executor/calculator/integer/subtract_integer_calculator.c"
-#include "../../../../../executor/copier/integer_copier.c"
-#include "../../../../../executor/representer/deserialiser/time_scale/running_day/running_day_time_scale_deserialiser.c"
-#include "../../../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "communication.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
 
 /**
  * Deserialises the source year/month/day into the destination julian day.
