@@ -19,22 +19,20 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef JULIAN_SECOND_GREGORIAN_CALENDAR_TIME_SCALE_DESERIALISER_SOURCE
 #define JULIAN_SECOND_GREGORIAN_CALENDAR_TIME_SCALE_DESERIALISER_SOURCE
 
-#include "../../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../../constant/model/cyboi/state/double_state_cyboi_model.c"
-#include "../../../../../constant/model/time_scale/duration_time_scale_model.c"
-#include "../../../../../executor/calculator/double/add_double_calculator.c"
-#include "../../../../../executor/calculator/double/divide_double_calculator.c"
-#include "../../../../../executor/calculator/double/multiply_double_calculator.c"
-#include "../../../../../executor/caster/double/integer_double_caster.c"
-#include "../../../../../executor/copier/double_copier.c"
-#include "../../../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Deserialises the hour/minute/second into a julian second.
