@@ -19,15 +19,21 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef HTTP_URI_DESERIALISER_SOURCE
 #define HTTP_URI_DESERIALISER_SOURCE
 
-#include "../../../../executor/representer/deserialiser/uri/http/authority_http_uri_deserialiser.c"
-#include "../../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "communication.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
 
 /**
  * Deserialises the http uri into a part model and -properties.
