@@ -19,24 +19,28 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef WIN32_DISPLAY_DESERIALISER_SOURCE
 #define WIN32_DISPLAY_DESERIALISER_SOURCE
 
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
 #include <windowsx.h>
 
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../../constant/name/cybol/state/gui/event_gui_state_cybol_name.c"
-#include "../../../../constant/name/cybol/state/keyboard/keyboard_state_cybol_name.c"
-#include "../../../../constant/name/cybol/state/mouse/mouse_state_cybol_name.c"
-#include "../../../../executor/representer/deserialiser.c"
-#include "../../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
 
 /**
  * Deserialises the win32 event message.
