@@ -19,21 +19,23 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef ELEMENTS_QYYYY_DATETIME_XDT_DESERIALISER_SOURCE
 #define ELEMENTS_QYYYY_DATETIME_XDT_DESERIALISER_SOURCE
 
-#include "../../../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../../../../constant/model/numeral/base_numeral_model.c"
-#include "../../../../../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../../../../../executor/representer/deserialiser/numeral/integer_numeral_deserialiser.c"
-#include "../../../../../../executor/representer/deserialiser/xdt/datetime/qyyyy/quarter_qyyyy_datetime_xdt_deserialiser.c"
-#include "../../../../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "communication.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
+#include "type.h"
+#include "xdt.h"
 
 /**
  * Deserialises the source qyyyy elements wide character data into the destination datetime item.
