@@ -19,29 +19,30 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef CONSTRAINTS_FIELD_XDT_DESERIALISER_SOURCE
 #define CONSTRAINTS_FIELD_XDT_DESERIALISER_SOURCE
 
-#include "../../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../../../constant/model/cyboi/state/state_cyboi_model.c"
-#include "../../../../../constant/name/cyboi/state/item_state_cyboi_name.c"
-#include "../../../../../constant/name/cyboi/state/part_state_cyboi_name.c"
-#include "../../../../../constant/name/cyboi/state/primitive_state_cyboi_name.c"
-#include "../../../../../constant/name/cybol/state/language_state_cybol_name.c"
-#include "../../../../../constant/name/numeral/decimal_numeral_name.c"
-#include "../../../../../constant/name/numeral/thousands_numeral_name.c"
-#include "../../../../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../../../../executor/accessor/getter/part/name_part_getter.c"
-#include "../../../../../executor/copier/array_copier.c"
-#include "../../../../../executor/copier/integer_copier.c"
-#include "../../../../../executor/representer/deserialiser/xdt/field/model_field_xdt_deserialiser.c"
-#include "../../../../../logger/logger.c"
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "communication.h"
+#include "constant.h"
+#include "cybol.h"
+#include "knowledge.h"
+#include "logger.h"
+#include "xdt.h"
 
 /**
  * Retrieves language properties (constraints) necessary for deserialisation.
