@@ -19,27 +19,29 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef PART_FIELD_XDT_DESERIALISER_SOURCE
 #define PART_FIELD_XDT_DESERIALISER_SOURCE
 
-#include "../../../../../constant/format/cyboi/logic_cyboi_format.c"
-#include "../../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../../../constant/model/cyboi/state/negative_integer_state_cyboi_model.c"
-#include "../../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../../../executor/copier/array_copier.c"
-#include "../../../../../executor/memoriser/allocator/part_allocator.c"
-#include "../../../../../executor/modifier/item_modifier.c"
-#include "../../../../../executor/modifier/part_modifier.c"
-#include "../../../../../executor/representer/deserialiser/xdt/field/constraints_field_xdt_deserialiser.c"
-#include "../../../../../executor/representer/deserialiser/xdt/field/format_field_xdt_deserialiser.c"
-#include "../../../../../executor/representer/deserialiser/xdt/field/type_field_xdt_deserialiser.c"
-#include "../../../../../logger/logger.c"
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "communication.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
+#include "xdt.h"
 
 /**
  * Deserialises xdt field part.
