@@ -19,20 +19,22 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef STANDARD_XDT_DESERIALISER_SOURCE
 #define STANDARD_XDT_DESERIALISER_SOURCE
 
-#include "../../../../constant/language/cyboi/state_cyboi_language.c"
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../../executor/representer/deserialiser/xdt/bdt/bdt_xdt_deserialiser.c"
-#include "../../../../executor/representer/deserialiser/xdt/gdt/gdt_xdt_deserialiser.c"
-#include "../../../../executor/representer/deserialiser/xdt/ldt/ldt_xdt_deserialiser.c"
-#include "../../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "communication.h"
+#include "constant.h"
+#include "logger.h"
+#include "xdt.h"
 
 /**
  * Deserialises xdt standard data.
