@@ -19,26 +19,28 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef ENCODING_CYBOL_SERIALISER_SOURCE
 #define ENCODING_CYBOL_SERIALISER_SOURCE
 
-#include "../../../../constant/encoding/cyboi/cyboi_encoding.c"
-#include "../../../../constant/encoding/cybol/cybol_encoding.c"
-#include "../../../../constant/encoding/cybol/base_cybol_encoding.c"
-#include "../../../../constant/encoding/cybol/dos_cybol_encoding.c"
-#include "../../../../constant/encoding/cybol/iso_8859_cybol_encoding.c"
-#include "../../../../constant/encoding/cybol/unicode_cybol_encoding.c"
-#include "../../../../constant/encoding/cybol/windows_cybol_encoding.c"
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../../../executor/comparator/integer/equal_integer_comparator.c"
-#include "../../../../executor/copier/integer_copier.c"
-#include "../../../../logger/logger.c"
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
 
 /**
  * Serialises the cyboi encoding into a cybol encoding.
