@@ -19,26 +19,28 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef LANGUAGE_CYBOL_SERIALISER_SOURCE
 #define LANGUAGE_CYBOL_SERIALISER_SOURCE
 
-#include "../../../../constant/language/cyboi/state_cyboi_language.c"
-#include "../../../../constant/language/cybol/state/application_state_cybol_language.c"
-#include "../../../../constant/language/cybol/state/chronology_state_cybol_language.c"
-#include "../../../../constant/language/cybol/state/interface_state_cybol_language.c"
-#include "../../../../constant/language/cybol/state/message_state_cybol_language.c"
-#include "../../../../constant/language/cybol/state/number_state_cybol_language.c"
-#include "../../../../constant/language/cybol/state/text_state_cybol_language.c"
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../../executor/comparator/integer/equal_integer_comparator.c"
-#include "../../../../executor/modifier/item_modifier.c"
-#include "../../../../executor/copier/integer_copier.c"
-#include "../../../../logger/logger.c"
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
 
 /**
  * Serialises the cyboi runtime language into a cybol language.
