@@ -19,17 +19,20 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef JD_DATETIME_SERIALISER_SOURCE
 #define JD_DATETIME_SERIALISER_SOURCE
 
-#include "../../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../../constant/model/time_scale/julian_date_time_scale_model.c"
-#include "../../../../../executor/representer/serialiser/datetime/jd/basic_jd_datetime_serialiser.c"
-#include "../../../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "communication.h"
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Serialises the datetime into julian date (jd) wide character data.
