@@ -19,15 +19,18 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef ISO_DURATION_SERIALISER_SOURCE
 #define ISO_DURATION_SERIALISER_SOURCE
 
-#include "../../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "logger.h"
 
 /**
  * Serialises the duration model into an iso duration.
