@@ -19,25 +19,19 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef CLEANUP_GUI_SERIALISER_SOURCE
 #define CLEANUP_GUI_SERIALISER_SOURCE
 
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../logger/logger.c"
+//
+// Library interface
+//
 
-#if defined(__linux__) || defined(__unix__)
-    #include "../../../../executor/representer/serialiser/xcb/cleanup_xcb_serialiser.c"
-#elif defined(__APPLE__) && defined(__MACH__)
-    //?? TODO: Add support for Cocoa
-// Use __CYGWIN__ too, if _WIN32 is not known to mingw.
-#elif defined(_WIN32) || defined(__CYGWIN__)
-#else
-    #error "Could not compile system. The operating system is not supported. Check out defined preprocessor macros!"
-#endif
+#include "communication.h"
+#include "logger.h"
 
 /**
  * Cleans up the gui context.
