@@ -19,17 +19,41 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef INITIAL_GUI_SERIALISER_SOURCE
 #define INITIAL_GUI_SERIALISER_SOURCE
 
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../../constant/name/cyboi/state/internal_memory_state_cyboi_name.c"
-#include "../../../../executor/copier/array_copier.c"
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "algorithm.h"
+#include "communication.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
+
+//
+// Forbidden interface
+//
+// CAUTION! Do NOT include the following files since otherwise,
+// circular references would occur due to module dependencies.
+// Instead, forward declarations are used further below.
+// Therefore, the following includes are to be commented OUT
+// and listed here just for information.
+//
+
+//?? TODO:
 //
 // CAUTION! Do NOT include the "content_gui_serialiser.c" module.
 // It is true, the "serialise_gui_content" function is called from here,
@@ -37,8 +61,6 @@
 // by module granularity and NOT by call hierarchy.
 // Therefore, the "gui_serialiser.c" module is included here.
 //
-#include "../../../../executor/representer/serialiser/gui/gui_serialiser.c"
-#include "../../../../logger/logger.c"
 
 /**
  * Initialises the gui serialiser.
