@@ -19,27 +19,21 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef CONTENT_HTML_SERIALISER_SOURCE
 #define CONTENT_HTML_SERIALISER_SOURCE
 
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../../constant/name/cybol/state/wui/tag_wui_state_cybol_name.c"
-#include "../../../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../../../executor/representer/serialiser/html/begin_html_serialiser.c"
-#include "../../../../executor/representer/serialiser/html/break_html_serialiser.c"
-#include "../../../../executor/representer/serialiser/html/doctype_html_serialiser.c"
-#include "../../../../executor/representer/serialiser/html/empty_html_serialiser.c"
-#include "../../../../executor/representer/serialiser/html/end_html_serialiser.c"
-#include "../../../../executor/representer/serialiser/html/filled_html_serialiser.c"
-#include "../../../../executor/representer/serialiser/html/indentation_html_serialiser.c"
-#include "../../../../executor/representer/serialiser/html/void_html_serialiser.c"
-#include "../../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "communication.h"
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Serialises the part element content into html.
