@@ -19,26 +19,22 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef SIZE_GRID_LAYOUT_SERIALISER_SOURCE
 #define SIZE_GRID_LAYOUT_SERIALISER_SOURCE
 
-#include "../../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../../../constant/name/cybol/state/layout/grid_layout_state_cybol_name.c"
-#include "../../../../../executor/accessor/getter/part/name_part_getter.c"
-#include "../../../../../executor/calculator/integer/add_integer_calculator.c"
-#include "../../../../../executor/calculator/integer/multiply_integer_calculator.c"
-#include "../../../../../executor/calculator/integer/subtract_integer_calculator.c"
-#include "../../../../../executor/comparator/integer/greater_integer_comparator.c"
-#include "../../../../../executor/copier/array_copier.c"
-#include "../../../../../executor/copier/integer_copier.c"
-#include "../../../../../executor/representer/serialiser/layout/part_layout_serialiser.c"
-#include "../../../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "communication.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
 
 /**
  * Serialises grid layout size.
