@@ -19,21 +19,28 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef POSITION_LAYOUT_SERIALISER_SOURCE
 #define POSITION_LAYOUT_SERIALISER_SOURCE
 
-#include "../../../../constant/format/cyboi/logic_cyboi_format.c"
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../../constant/model/cybol/layout/layout_cybol_model.c"
-#include "../../../../executor/checker/operation_checker.c"
-#include "../../../../executor/representer/serialiser/layout/absolute/position_absolute_layout_serialiser.c"
-#include "../../../../executor/representer/serialiser/layout/grid/position_grid_layout_serialiser.c"
-#include "../../../../logger/logger.c"
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "communication.h"
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Serialises layout position.
