@@ -19,36 +19,30 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef DECIMAL_FRACTION_NUMERAL_SERIALISER_SOURCE
 #define DECIMAL_FRACTION_NUMERAL_SERIALISER_SOURCE
 
-#include "../../../../constant/format/cyboi/logic_cyboi_format.c"
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/double_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/negative_integer_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../../constant/name/numeral/decimal_numeral_name.c"
-#include "../../../../constant/name/numeral/power_numeral_name.c"
-#include "../../../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../../../executor/calculator/double/absolute_double_calculator.c"
-#include "../../../../executor/calculator/double/scientific_double_calculator.c"
-#include "../../../../executor/calculator/double/subtract_double_calculator.c"
-#include "../../../../executor/calculator/integer/absolute_integer_calculator.c"
-#include "../../../../executor/caster/double/integer_double_caster.c"
-#include "../../../../executor/caster/integer/double_integer_caster.c"
-#include "../../../../executor/comparator/double/less_double_comparator.c"
-#include "../../../../executor/comparator/integer/unequal_integer_comparator.c"
-#include "../../../../executor/copier/double_copier.c"
-#include "../../../../executor/modifier/item_modifier.c"
-#include "../../../../executor/representer/serialiser/numeral/decimals_numeral_serialiser.c"
-#include "../../../../executor/representer/serialiser/numeral/integer_numeral_serialiser.c"
-#include "../../../../logger/logger.c"
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "communication.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
+#include "type.h"
 
 /**
  * Serialises the decimal fraction into a wide character sequence.
