@@ -19,23 +19,29 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef NUMERAL_SERIALISER_SOURCE
 #define NUMERAL_SERIALISER_SOURCE
 
-#include "../../../../constant/format/cyboi/state_cyboi_format.c"
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../../executor/comparator/integer/equal_integer_comparator.c"
-#include "../../../../executor/representer/serialiser/numeral/cartesian_complex_numeral_serialiser.c"
-#include "../../../../executor/representer/serialiser/numeral/decimal_fraction_numeral_serialiser.c"
-#include "../../../../executor/representer/serialiser/numeral/integer_numeral_serialiser.c"
-#include "../../../../executor/representer/serialiser/numeral/polar_complex_numeral_serialiser.c"
-#include "../../../../executor/representer/serialiser/numeral/vulgar_fraction_numeral_serialiser.c"
-#include "../../../../logger/logger.c"
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "communication.h"
+#include "constant.h"
+#include "logger.h"
+#include "type.h"
 
 /**
  * Serialises the source number into a wide character numeral sequence.
