@@ -19,24 +19,25 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef JULIAN_CALENDAR_TIME_SCALE_SERIALISER_SOURCE
 #define JULIAN_CALENDAR_TIME_SCALE_SERIALISER_SOURCE
 
-#include "../../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../../constant/model/cyboi/state/double_state_cyboi_model.c"
-#include "../../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../../../constant/name/cyboi/state/datetime_state_cyboi_name.c"
-#include "../../../../../executor/accessor/setter/datetime_setter.c"
-/*??
-#include "../../../../../executor/representer/deserialiser/time_scale/julian_calendar/julian_day_julian_calendar_time_scale_deserialiser.c"
-#include "../../../../../executor/representer/deserialiser/time_scale/julian_calendar/julian_second_julian_calendar_time_scale_deserialiser.c"
-#include "../../../../../executor/representer/deserialiser/time_scale/julian_calendar/normalise_julian_calendar_time_scale_deserialiser.c"
-*/
-#include "../../../../../logger/logger.c"
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "logger.h"
 
 /**
  * Serialises the source datetime into the destination julian calendar date.
