@@ -19,19 +19,25 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef RECTANGLE_WIN32_DISPLAY_SERIALISER_SOURCE
 #define RECTANGLE_WIN32_DISPLAY_SERIALISER_SOURCE
 
+//
+// System interface
+//
+
 #include <windows.h>
 
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Serialises the rectangle into win32 display.
@@ -95,7 +101,7 @@ void serialise_win32_display_rectangle(void* p0, void* p1, void* p2, void* p3, v
                             DWORD e = GetLastError();
 
                             log_message_terminated((void*) ERROR_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not serialise win32 display rectangle. A windows system error occured.");
-                            log_windows_system_error((void*) &e);
+                            log_error((void*) &e);
                         }
 
                     } else {
