@@ -19,29 +19,27 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef PROPERTIES_CONTEXT_XCB_SERIALISER_SOURCE
 #define PROPERTIES_CONTEXT_XCB_SERIALISER_SOURCE
 
+//
+// System interface
+//
+
 #include <xcb/xcb.h>
 
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../../constant/name/cybol/state/gui/gui_state_cybol_name.c"
-#include "../../../../executor/accessor/getter/part/name_part_getter.c"
-#include "../../../../executor/copier/array_copier.c"
-#include "../../../../executor/copier/integer_copier.c"
-#include "../../../../executor/representer/serialiser/xcb/cap_style_xcb_serialiser.c"
-#include "../../../../executor/representer/serialiser/xcb/fill_rule_xcb_serialiser.c"
-#include "../../../../executor/representer/serialiser/xcb/fill_style_xcb_serialiser.c"
-#include "../../../../executor/representer/serialiser/xcb/join_style_xcb_serialiser.c"
-#include "../../../../executor/representer/serialiser/xcb/line_style_xcb_serialiser.c"
-#include "../../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "communication.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
 
 /**
  * Serialises the xcb context properties.
