@@ -19,29 +19,22 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef QUARTER_QYYYY_DATETIME_XDT_SERIALISER_SOURCE
 #define QUARTER_QYYYY_DATETIME_XDT_SERIALISER_SOURCE
 
-#include "../../../../../../constant/model/character_code/unicode/unicode_character_code_model.c"
-#include "../../../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../../../../constant/model/cyboi/state/double_state_cyboi_model.c"
-#include "../../../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../../../../constant/model/cyboi/state/state_cyboi_model.c"
-#include "../../../../../../constant/name/cyboi/state/primitive_state_cyboi_name.c"
-#include "../../../../../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../../../../../executor/comparator/integer/equal_integer_comparator.c"
-#include "../../../../../../executor/memoriser/allocator/item_allocator.c"
-#include "../../../../../../executor/memoriser/deallocator/item_deallocator.c"
-#include "../../../../../../executor/modifier/item_modifier.c"
-#include "../../../../../../executor/copier/array_copier.c"
-#include "../../../../../../executor/representer/serialiser/time_scale/gregorian_calendar/gregorian_calendar_time_scale_serialiser.c"
-#include "../../../../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "communication.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
 
 /**
  * Serialises the source month into the destination quarter.
