@@ -19,26 +19,29 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef CONTENT_XML_SERIALISER_SOURCE
 #define CONTENT_XML_SERIALISER_SOURCE
 
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../../constant/name/cybol/state/wui/tag_wui_state_cybol_name.c"
-#include "../../../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../../../executor/representer/serialiser/character_reference/character_reference_serialiser.c"
-#include "../../../../executor/representer/serialiser/xml/begin_xml_serialiser.c"
-#include "../../../../executor/representer/serialiser/xml/break_xml_serialiser.c"
-#include "../../../../executor/representer/serialiser/xml/empty_xml_serialiser.c"
-#include "../../../../executor/representer/serialiser/xml/end_xml_serialiser.c"
-#include "../../../../executor/representer/serialiser/xml/filled_xml_serialiser.c"
-#include "../../../../executor/representer/serialiser/xml/indentation_xml_serialiser.c"
-#include "../../../../logger/logger.c"
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "communication.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
 
 /**
  * Serialises the part element content into xml.
