@@ -19,24 +19,21 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef EXECUTOR_SOURCE
 #define EXECUTOR_SOURCE
 
+//
+// System interface
+//
+
 #include <sys/types.h>
 #include <errno.h>
-
-#include "../../constant/model/command/unix_command_model.c"
-#include "../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../constant/model/cyboi/state/negative_integer_state_cyboi_model.c"
-#include "../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../constant/name/command_option/unix/shell_unix_command_option_name.c"
-#include "../../executor/converter/encoder/utf/utf_8_encoder.c"
-#include "../../logger/logger.c"
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
 
 #if defined(__linux__) || defined(__unix__)
     #include <sys/wait.h>
@@ -49,6 +46,16 @@
     #error "Could not compile system. The operating system is not supported. Check out defined preprocessor macros!"
 #endif
 
+//
+// Library interface
+//
+
+#include "communication.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
+#include "shell.h"
+
 /**
  * Executes the command as process.
  *
@@ -161,7 +168,7 @@ void execute(void* p0, void* p1) {
     //
     // Initialise error number.
     //
-    // It is a global variable/ function and other operations
+    // It is a global variable/function and other operations
     // may have set some value that is not wanted here.
     //
     errno = *NUMBER_0_INTEGER_STATE_CYBOI_MODEL;
@@ -309,7 +316,7 @@ void execute(void* p0, void* p1) {
         //
         // Initialise error number.
         //
-        // It is a global variable/ function and other operations
+        // It is a global variable/function and other operations
         // may have set some value that is not wanted here.
         //
         errno = *NUMBER_0_INTEGER_STATE_CYBOI_MODEL;
