@@ -19,23 +19,22 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef HOSTNAME_AUTHORITY_SELECTOR_SOURCE
 #define HOSTNAME_AUTHORITY_SELECTOR_SOURCE
 
-#include "../../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../constant/name/authority/separator_authority_name.c"
-#include "../../../executor/calculator/integer/add_integer_calculator.c"
-#include "../../../executor/detector/detector.c"
-#include "../../../executor/mover/mover.c"
-#include "../../../executor/representer/deserialiser/authority/port_authority_deserialiser.c"
-#include "../../../logger/logger.c"
-#include "../../../variable/type_size/integral_type_size.c"
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "communication.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
 
 /**
  * Selects the authority hostname.
