@@ -19,28 +19,28 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef HEADER_FIELD_HTTP_REQUEST_SELECTOR_SOURCE
 #define HEADER_FIELD_HTTP_REQUEST_SELECTOR_SOURCE
 
-#include "../../../constant/format/cyboi/state_cyboi_format.c"
-#include "../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../constant/name/cyboi/http/header/entity_header_http_cyboi_name.c"
-#include "../../../constant/name/cyboi/http/header/general_header_http_cyboi_name.c"
-#include "../../../constant/name/cyboi/http/header/request_header_http_cyboi_name.c"
-#include "../../../constant/name/cyboi/http/header/response_header_http_cyboi_name.c"
-#include "../../../constant/name/http/header/entity_header_http_name.c"
-#include "../../../constant/name/http/header/general_header_http_name.c"
-#include "../../../constant/name/http/header/request_header_http_name.c"
-#include "../../../constant/name/http/header/response_header_http_name.c"
-#include "../../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../../executor/checker/operation_checker.c"
-#include "../../../executor/representer/deserialiser/http_request/decode_http_request_deserialiser.c"
-#include "../../../logger/logger.c"
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "communication.h"
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Selects the http request header field.
