@@ -19,21 +19,21 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef ABSOLUTE_URI_HTTP_REQUEST_URI_SELECTOR_SOURCE
 #define ABSOLUTE_URI_HTTP_REQUEST_URI_SELECTOR_SOURCE
 
-#include "../../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../constant/model/uri/scheme_uri_model.c"
-#include "../../../constant/name/http_request_uri/http_request_uri_name.c"
-#include "../../../executor/representer/deserialiser/uri/http_uri_deserialiser.c"
-#include "../../../executor/mover/mover.c"
-#include "../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "communication.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
 
 /**
  * Selects absolute uri http request uri.
