@@ -19,27 +19,28 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef VALUE_END_JOINED_STRING_SELECTOR_SOURCE
 #define VALUE_END_JOINED_STRING_SELECTOR_SOURCE
 
-#include "../../../constant/format/cyboi/logic_cyboi_format.c"
-#include "../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/state_cyboi_model.c"
-#include "../../../constant/name/cyboi/state/primitive_state_cyboi_name.c"
-#include "../../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../../executor/copier/integer_copier.c"
-#include "../../../executor/copier/pointer_copier.c"
-#include "../../../executor/detector/detector.c"
-#include "../../../executor/modifier/item_modifier.c"
-#include "../../../executor/mover/mover.c"
-#include "../../../logger/logger.c"
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "communication.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
 
 /**
  * Selects the joined string value end by searching for the given delimiter sequence.
