@@ -19,31 +19,29 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef BEGIN_VALUE_JSON_SELECTOR_SOURCE
 #define BEGIN_VALUE_JSON_SELECTOR_SOURCE
 
-#include "../../../constant/format/cyboi/state_cyboi_format.c"
-#include "../../../constant/model/character_code/unicode/unicode_character_code_model.c"
-#include "../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/state_cyboi_model.c"
-#include "../../../constant/model/json/json_model.c"
-#include "../../../constant/name/json/json_name.c"
-#include "../../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../../executor/copier/integer_copier.c"
-#include "../../../executor/detector/detector.c"
-#include "../../../executor/modifier/appender/item/part_item_appender.c"
-#include "../../../executor/mover/mover.c"
-#include "../../../executor/representer/deserialiser/json/array_json_deserialiser.c"
-#include "../../../executor/representer/deserialiser/json/number_json_deserialiser.c"
-#include "../../../executor/representer/deserialiser/json/object_json_deserialiser.c"
-#include "../../../executor/selector/json/type_string_json_selector.c"
-#include "../../../logger/logger.c"
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "communication.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
+#include "text.h"
 
 /**
  * Selects the json value begin.
