@@ -19,27 +19,28 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef BEGIN_KNOWLEDGE_SELECTOR_SOURCE
 #define BEGIN_KNOWLEDGE_SELECTOR_SOURCE
 
-#include "../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../constant/name/cyboi/knowledge/separator_knowledge_cyboi_name.c"
-#include "../../../constant/name/cyboi/state/part_state_cyboi_name.c"
-#include "../../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../../executor/copier/integer_copier.c"
-#include "../../../executor/detector/detector.c"
-#include "../../../executor/representer/deserialiser/knowledge/identification_knowledge_deserialiser.c"
-#include "../../../executor/representer/deserialiser/knowledge/name_knowledge_deserialiser.c"
-#include "../../../executor/representer/deserialiser/knowledge/part_knowledge_deserialiser.c"
-#include "../../../executor/representer/deserialiser/knowledge/reference_knowledge_deserialiser.c"
-#include "../../../logger/logger.c"
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "communication.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
 
 /**
  * Selects the knowledge begin.
