@@ -19,18 +19,20 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef MOVE_KNOWLEDGE_SELECTOR_SOURCE
 #define MOVE_KNOWLEDGE_SELECTOR_SOURCE
 
-#include "../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../executor/selector/knowledge/end_knowledge_selector.c"
-#include "../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "communication.h"
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Selects the knowledge end with the move depending on the given flag.
