@@ -19,27 +19,37 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef PARAMETRE_QUERY_HTTP_URI_SELECTOR_SOURCE
 #define PARAMETRE_QUERY_HTTP_URI_SELECTOR_SOURCE
 
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../../constant/name/cyboi/uri/uri_cyboi_name.c"
-#include "../../../../constant/name/uri/separator_uri_name.c"
-#include "../../../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../../../executor/calculator/integer/add_integer_calculator.c"
-#include "../../../../executor/detector/detector.c"
-#include "../../../../executor/mover/mover.c"
-#include "../../../../executor/representer/deserialiser/uri/http/fragment_http_uri_deserialiser.c"
-#include "../../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "communication.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
 
 //
-// Forward declarations
+// Forbidden interface
+//
+// CAUTION! Do NOT include the following files since otherwise,
+// circular references would occur due to module dependencies.
+// Instead, forward declarations are used further below.
+// Therefore, the following includes are to be commented OUT
+// and listed here just for information.
+//
+
+// #include "../../../../executor/representer/deserialiser/uri/http/parametre_query_http_uri_deserialiser.c"
+
+//
+// Forward declaration
 //
 
 void deserialise_http_uri_query_parametre(void* p0, void* p1, void* p2, void* p3);
