@@ -19,19 +19,21 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef NUMBER_3511_END_COMPOUND_FIELD_BDT_XDT_SELECTOR_SOURCE
 #define NUMBER_3511_END_COMPOUND_FIELD_BDT_XDT_SELECTOR_SOURCE
 
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../../executor/comparator/integer/equal_integer_comparator.c"
-#include "../../../../executor/copier/integer_copier.c"
-#include "../../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
 
 /**
  * Checks if the field is permitted to be a child of the given compound field.
@@ -127,7 +129,7 @@ void select_xdt_bdt_field_compound_end_3511(void* p0, void* p1) {
 
         compare_integer_equal((void*) &r, p1, (void*) NUMBER_8201_INTEGER_STATE_CYBOI_MODEL);
     }
-    
+
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
         // The source field did NOT match any of the
