@@ -19,19 +19,20 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef PROCESS_WIN32_CONSOLE_READER_SOURCE
 #define PROCESS_WIN32_CONSOLE_READER_SOURCE
 
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../../../../executor/streamer/reader/win32_console/key_process_win32_console_reader.c"
-#include "../../../../executor/streamer/reader/win32_console/mouse_process_win32_console_reader.c"
-#include "../../../../executor/streamer/reader/win32_console/window_buffer_size_process_win32_console_reader.c"
-#include "../../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "communication.h"
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Processes a win32 console message.
