@@ -19,19 +19,25 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef WINSOCK_READER_SOURCE
 #define WINSOCK_READER_SOURCE
 
+//
+// System interface
+//
+
 #include <winsock.h>
 
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../../logger/logger.c"
+//
+// Library interface
+//
+
+#include "constant.h"
+#include "logger.h"
 
 /**
  * Reads data via winsock and stores them in the given destination array.
@@ -180,7 +186,7 @@ void read_winsock(void* p0, void* p1, void* p2, void* p3, void* p4) {
                         // Cast int to DWORD (unsigned int 32-Bit).
                         DWORD dw = (DWORD) e;
 
-                        log_windows_system_error((void*) &dw);
+                        log_error((void*) &dw);
                     }
 
                 } else {
