@@ -19,23 +19,30 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef EXCLUSIVE_INTERRUPT_PIPE_WRITER_SOURCE
 #define EXCLUSIVE_INTERRUPT_PIPE_WRITER_SOURCE
 
-#include <stddef.h> // size_t
-#include <unistd.h> // write
+//
+// System interface
+//
 
-#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../../executor/porter/locker.c"
-#include "../../../../executor/porter/unlocker.c"
-#include "../../../../logger/logger.c"
-#include "../../../../variable/type_size/integral_type_size.c"
-#include "../../../../variable/type_size/pointer_type_size.c"
+#include <stddef.h> // size_t
+#include <stdio.h> // stdout
+#include <unistd.h> // write
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "constant.h"
+#include "logger.h"
+#include "system.h"
+#include "variable.h"
 
 /**
  * Locks the mutex and writes the handler to the interrupt pipe.
