@@ -19,20 +19,28 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef CUTTER_SOURCE
 #define CUTTER_SOURCE
 
-#include <threads.h> // thrd_t, thrd_equal, thrd_join, thrd_error
+//
+// System interface
+//
 
-#include "../../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../logger/logger.c"
-#include "../../variable/thread_identification.c"
+#include <stdio.h> // stdout
+#include <threads.h> // thrd_t, thrd_equal, thrd_join, thrd_error
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "constant.h"
+#include "logger.h"
+#include "variable.h"
 
 /**
  * Cuts the thread, that is wait for it to exit.
