@@ -19,20 +19,28 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.25.0 2023-03-01
+ * @version CYBOP 0.26.0 2023-04-04
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef CHANNEL_TO_TYPE_MAPPER_SOURCE
 #define CHANNEL_TO_TYPE_MAPPER_SOURCE
 
-#include "../constant/channel/cyboi/cyboi_channel.c"
-#include "../constant/model/cyboi/log/level_log_cyboi_model.c"
-#include "../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../constant/type/cyboi/state_cyboi_type.c"
-#include "../executor/comparator/integer/equal_integer_comparator.c"
-#include "../executor/copier/integer_copier.c"
-#include "../logger/logger.c"
+//
+// System interface
+//
+
+#include <stdio.h> // stdout
+#include <wchar.h> // fwprintf
+
+//
+// Library interface
+//
+
+#include "arithmetic.h"
+#include "constant.h"
+#include "knowledge.h"
+#include "logger.h"
 
 /**
  * Maps the channel to a data type.
